@@ -1,3 +1,7 @@
+/**
+ * @file
+ * jQuery to provide summary information inside vertical tabs.
+ */
 
 (function ($) {
 
@@ -6,8 +10,16 @@
  */
 Drupal.behaviors.scheduler_settings = {
   attach: function (context) {
-	// Provide summary when editting a node.
-	$('fieldset#edit-scheduler-settings', context).drupalSetSummary(function(context) {
+
+    // Add the theme name as an additional class to the vertical-tabs div. This
+    // can then be used in scheduler.css to rectify the style for collapsible
+    // fieldsets where different themes need slightly different fixes. The theme
+    // is available in ajaxPageState.
+    var theme = Drupal.settings.ajaxPageState['theme'];
+    $('div.vertical-tabs').addClass(theme);
+
+    // Provide summary when editing a node.
+    $('fieldset#edit-scheduler-settings', context).drupalSetSummary(function(context) {
       var vals = [];
       if ($('#edit-publish-on').val() || $('#edit-publish-on-datepicker-popup-0').val()) {
         vals.push(Drupal.t('Scheduled for publishing'));
@@ -32,7 +44,6 @@ Drupal.behaviors.scheduler_settings = {
       }
       return vals.join('<br/>');
     });
-
   }
 };
 
